@@ -12,12 +12,6 @@ import os
 label = "PyFstat_example_grid_search_F0F1"
 outdir = os.path.join("PyFstat_example_data", label)
 
-F0 = 30.0
-F1 = 1e-10
-F2 = 0
-Alpha = 1.0
-Delta = 1.5
-
 # Properties of the GW data
 sqrtSX = 1e-23
 tstart = 1000000000
@@ -26,56 +20,73 @@ tend = tstart + duration
 tref = 0.5 * (tstart + tend)
 IFOs = "H1"
 
+# parameters for injected signals
 depth = 20
-
-h0 = sqrtSX / depth
-cosi = 0
+inj = {
+    "tref": tref,
+    "F0": 30.0,
+    "F1": -1e-10,
+    "F2": 0,
+    "Alpha": 1.0,
+    "Delta": 1.5,
+    "h0": sqrtSX / depth,
+    "cosi": 0.0,
+}
 
 data = pyfstat.Writer(
     label=label,
     outdir=outdir,
-    tref=tref,
     tstart=tstart,
-    F0=F0,
-    F1=F1,
-    F2=F2,
     duration=duration,
-    Alpha=Alpha,
-    Delta=Delta,
-    h0=h0,
-    cosi=cosi,
     sqrtSX=sqrtSX,
     detectors=IFOs,
+    **inj,
 )
 data.make_data()
 
 m = 0.01
 dF0 = np.sqrt(12 * m) / (np.pi * duration)
-dF1 = np.sqrt(180 * m) / (np.pi * duration ** 2)
+dF1 = np.sqrt(180 * m) / (np.pi * duration**2)
 dF2 = 1e-17
 N = 100
 DeltaF0 = N * dF0
 DeltaF1 = N * dF1
-F0s = [F0 - DeltaF0 / 2.0, F0 + DeltaF0 / 2.0, dF0]
-F1s = [F1 - DeltaF1 / 2.0, F1 + DeltaF1 / 2.0, dF1]
-F2s = [F2]
-Alphas = [Alpha]
-Deltas = [Delta]
+F0s = [inj["F0"] - DeltaF0 / 2.0, inj["F0"] + DeltaF0 / 2.0, dF0]
+F1s = [inj["F1"] - DeltaF1 / 2.0, inj["F1"] + DeltaF1 / 2.0, dF1]
+F2s = [inj["F2"]]
+Alphas = [inj["Alpha"]]
+Deltas = [inj["Delta"]]
 search = pyfstat.GridSearch(
-    label,
-    outdir,
-    data.sftfilepath,
-    F0s,
-    F1s,
-    F2s,
-    Alphas,
-    Deltas,
-    tref,
-    tstart,
-    tend,
+    label=label,
+    outdir=outdir,
+    sftfilepattern=data.sftfilepath,
+    F0s=F0s,
+    F1s=F1s,
+    F2s=F2s,
+    Alphas=Alphas,
+    Deltas=Deltas,
+    tref=tref,
+    minStartTime=tstart,
+    maxStartTime=tend,
 )
 search.run()
 
+# report details of the maximum point
+max_dict = search.get_max_twoF()
+print(
+    "max2F={:.4f} from GridSearch, offsets from injection: {:s}.".format(
+        max_dict["twoF"],
+        ", ".join(
+            [
+                "{:.4e} in {:s}".format(max_dict[key] - inj[key], key)
+                for key in max_dict.keys()
+                if not key == "twoF"
+            ]
+        ),
+    )
+)
+search.generate_loudest()
+
 print("Plotting 2F(F0)...")
 search.plot_1D(xkey="F0", xlabel="freq [Hz]", ylabel="$2\\mathcal{F}$")
 print("Plotting 2F(F1)...")
@@ -84,8 +95,8 @@ print("Plotting 2F(F0,F1)...")
 search.plot_2D(xkey="F0", ykey="F1", colorbar=True)
 
 print("Making gridcorner plot...")
-F0_vals = np.unique(search.data["F0"]) - F0
-F1_vals = np.unique(search.data["F1"]) - F1
+F0_vals = np.unique(search.data["F0"]) - inj["F0"]
+F1_vals = np.unique(search.data["F1"]) - inj["F1"]
 twoF = search.data["twoF"].reshape((len(F0_vals), len(F1_vals)))
 xyz = [F0_vals, F1_vals]
 labels = [
