@@ -89,14 +89,8 @@ class BaseSearchClass:
             respectively at evenly spaced times, as passed to CreateFstatInput
         """
         earth_ephem_default, sun_ephem_default = helper_functions.get_ephemeris_files()
-        if earth_ephem is None:
-            self.earth_ephem = earth_ephem_default
-        else:
-            self.earth_ephem = earth_ephem
-        if sun_ephem is None:
-            self.sun_ephem = sun_ephem_default
-        else:
-            self.sun_ephem = sun_ephem
+        self.earth_ephem = earth_ephem or earth_ephem_default
+        self.sun_ephem = sun_ephem or sun_ephem_default
 
     def _set_init_params_dict(self, argsdict):
         """Store the initial input arguments, e.g. for logging output."""
@@ -590,7 +584,7 @@ class ComputeFstat(BaseSearchClass):
             cosi = self.injectSources["cosi"]
             use_aPlus = "aPlus" in dir(PP.Amp)
             if use_aPlus:  # lalsuite interface changed in aff93c45
-                PP.Amp.aPlus = 0.5 * h0 * (1.0 + cosi ** 2)
+                PP.Amp.aPlus = 0.5 * h0 * (1.0 + cosi**2)
                 PP.Amp.aCross = h0 * cosi
             else:
                 PP.Amp.h0 = h0
