@@ -439,7 +439,7 @@ class GridSearch(BaseSearchClass):
             elif f.endswith("f"):
                 decimals = int(re.findall(r"\d+", f)[-1])
                 rtol[key] = 0
-                atol[key] = 10 ** -decimals
+                atol[key] = 10**-decimals
             else:
                 raise ValueError(
                     "Cannot parse fprintf format '{:s}' to obtain recommended tolerance.".format(
@@ -488,7 +488,7 @@ class GridSearch(BaseSearchClass):
 
     def _convert_F1_to_mismatch(self, F1, F1hat, Tseg):
         DeltaF1 = F1[1] - F1[0]
-        m_spacing = (np.pi * Tseg ** 2 * DeltaF1) ** 2 / 720.0
+        m_spacing = (np.pi * Tseg**2 * DeltaF1) ** 2 / 720.0
         N = len(F1)
         return np.arange(-N * m_spacing / 2.0, N * m_spacing / 2.0, m_spacing)
 
@@ -780,6 +780,24 @@ class GridSearch(BaseSearchClass):
         for k, v in d.items():
             print("  {}={}".format(k, v))
 
+    def generate_loudest(self):
+        """Use lalapps_ComputeFstatistic_v2 to produce a .loudest file"""
+        max_params = self.get_max_twoF()
+        max_params.pop("twoF")
+        max_params = self.translate_keys_to_lal(max_params)
+        self.loudest_file = helper_functions.generate_loudest_file(
+            max_params=max_params,
+            tref=self.tref,
+            outdir=self.outdir,
+            label=self.label,
+            sftfilepattern=self.sftfilepattern,
+            minStartTime=self.minStartTime,
+            maxStartTime=self.maxStartTime,
+            transientWindowType=getattr(self, "transientWindowType", None),
+            earth_ephem=self.earth_ephem,
+            sun_ephem=self.sun_ephem,
+        )
+
     def set_out_file(self, extra_label=None):
         """Set (or reset) the name of the main output file.
 
