@@ -63,7 +63,11 @@ class pyTransientFstatMap:
     Attributes
     ----------
     F_mn: np.ndarray
-        2D array of F values (not 2F!).
+        2D array of F values (not 2F!),
+        with `m` an index over start-times `t0`,
+        and  `n` an index over duration parameters `tau`,
+        in steps of `dt0`  in `[t0,  t0+t0Band]`,
+        and `dtau` in `[tau, tau+tauBand]`.
     maxF: float
         Maximum of F (not 2F!) over the array.
     t0_ML: float
@@ -72,7 +76,7 @@ class pyTransientFstatMap:
         Maximum likelihood estimate of the transient duration `tau`.
     """
 
-    def __init__(self, N_t0Range, N_tauRange):
+    def __init__(self, N_t0Range=None, N_tauRange=None, transientFstatMap_t=None):
         """
         The class can be initialized with the following:
 
@@ -82,29 +86,82 @@ class pyTransientFstatMap:
             Number of `t0` values covered.
         N_tauRange: int
             Number of `tau` values covered.
+        transientFstatMap_t: lalpulsar.transientFstatMap_t
+            pre-allocated matrix from lalpulsar.
         """
+        if transientFstatMap_t:
+            self._init_from_lalpulsar_type(transientFstatMap_t)
+        else:
+            if not N_t0Range or not N_tauRange:
+                raise ValueError(
+                    "Need either a transientFstatMap_t or a pair of (N_t0Range, N_tauRange)!."
+                )
+            self.F_mn = np.zeros((N_t0Range, N_tauRange), dtype=np.float32)
+            # Initializing maxF to a negative value ensures
+            # that we always update at least once and hence return
+            # sane t0_d_ML, tau_d_ML
+            # even if there is only a single bin where F=0 happens.
+            self.maxF = float(-1.0)
+            self.t0_ML = float(0.0)
+            self.tau_ML = float(0.0)
 
-        self.F_mn = np.zeros((N_t0Range, N_tauRange), dtype=np.float32)
-        # Initializing maxF to a negative value ensures
-        # that we always update at least once and hence return
-        # sane t0_d_ML, tau_d_ML
-        # even if there is only a single bin where F=0 happens.
-        self.maxF = float(-1.0)
-        self.t0_ML = float(0.0)
-        self.tau_ML = float(0.0)
+    def _init_from_lalpulsar_type(self, transientFstatMap_t):
+        """This essentially just strips out a redundant member level from the lalpulsar structure."""
+        self.F_mn = transientFstatMap_t.F_mn.data
+        self.maxF = transientFstatMap_t.maxF
+        self.t0_ML = transientFstatMap_t.t0_ML
+        self.tau_ML = transientFstatMap_t.tau_ML
+
+    def get_maxF_idx(self):
+        """Gets the 2D-unravelled index pair of the maximum of the F_mn map
+
+        Returns
+        -------
+        idx: tuple
+            The m,n indices of the map entry with maximal F value.
+        """
+        return np.unravel_index(np.argmax(self.F_mn), self.F_mn.shape)
+
+    def write_F_mn_to_file(self, tCWfile, windowRange, header=[]):
+        """Format a 2D transient-F-stat matrix over `(t0,tau)` and write as a text file.
+
+        Apart from the optional extra header lines,
+        the format is consistent with lalpulsar.write_transientFstatMap_to_fp().
+
+        Parameters
+        ----------
+        tCWfile: str
+            Name of the file to write to.
+        windowRange: lalpulsar.transientWindowRange_t
+            A lalpulsar structure containing the transient parameters.
+        header: list
+            A list of additional header lines
+            to print at the start of the file.
+        """
+        with open(tCWfile, "w") as tfp:
+            for hline in header:
+                tfp.write("# {:s}\n".format(hline))
+            tfp.write("# t0[s]     tau[s]     2F\n")
+            for m, F_m in enumerate(self.F_mn):
+                this_t0 = windowRange.t0 + m * windowRange.dt0
+                for n, this_F in enumerate(F_m):
+                    this_tau = windowRange.tau + n * windowRange.dtau
+                    tfp.write(
+                        "  %10d %10d %- 11.8g\n" % (this_t0, this_tau, 2.0 * this_F)
+                    )
 
 
 fstatmap_versions = {
-    "lal": lambda multiFstatAtoms, windowRange: getattr(
-        lalpulsar, "ComputeTransientFstatMap"
-    )(multiFstatAtoms, windowRange, False),
+    "lal": lambda multiFstatAtoms, windowRange: lalpulsar_compute_transient_fstat_map(
+        multiFstatAtoms, windowRange
+    ),
     "pycuda": lambda multiFstatAtoms, windowRange: pycuda_compute_transient_fstat_map(
         multiFstatAtoms, windowRange
     ),
 }
 """Dictionary of the actual callable transient F-stat map functions this module supports.
 
-Actual runtime variability depends on the corresponding external modules
+Actual runtime availability depends on the corresponding external modules
 being available.
 """
 
@@ -196,7 +253,7 @@ def init_transient_fstat_map_features(wantCuda=False, cudaDeviceName=None):
             devnames[n] = devn.name().replace(" ", "-").replace("_", "-")
             logging.debug(
                 "device {}: model: {}, RAM: {}MB".format(
-                    n, devnames[n], devn.total_memory() / (2.0 ** 20)
+                    n, devnames[n], devn.total_memory() / (2.0**20)
                 )
             )
 
@@ -305,6 +362,32 @@ def call_compute_transient_fstat_map(
     return FstatMap, timingFstatMap
 
 
+def lalpulsar_compute_transient_fstat_map(multiFstatAtoms, windowRange):
+    """Wrapper for the standard lalpulsar function for computing a transient F-statistic map.
+
+    See https://lscsoft.docs.ligo.org/lalsuite/lalpulsar/_transient_c_w__utils_8h.html
+    for the wrapped function.
+
+    Parameters
+    ----------
+    multiFstatAtoms: lalpulsar.MultiFstatAtomVector
+        The time-dependent F-stat atoms previously computed by `ComputeFstat`.
+    windowRange: lalpulsar.transientWindowRange_t
+        The structure defining the transient parameters.
+
+    Returns
+    -------
+    FstatMap: pyTransientFstatMap
+        The computed results, see the class definition for details.
+    """
+    FstatMap_lalpulsar = lalpulsar.ComputeTransientFstatMap(
+        multiFstatAtoms=multiFstatAtoms,
+        windowRange=windowRange,
+        useFReg=False,
+    )
+    return pyTransientFstatMap(transientFstatMap_t=FstatMap_lalpulsar)
+
+
 def reshape_FstatAtomsVector(atomsVector):
     """Make a dictionary of ndarrays out of an F-stat atoms 'vector' structure.
 
@@ -355,8 +438,8 @@ def _get_absolute_kernel_path(kernel):
 
 
 def _print_GPU_memory_MB(key):
-    mem_used_MB = drv.mem_get_info()[0] / (2.0 ** 20)
-    mem_total_MB = drv.mem_get_info()[1] / (2.0 ** 20)
+    mem_used_MB = drv.mem_get_info()[0] / (2.0**20)
+    mem_total_MB = drv.mem_get_info()[1] / (2.0**20)
     logging.debug(
         "{} GPU memory: {:.4f} / {:.4f} MB free".format(key, mem_used_MB, mem_total_MB)
     )
@@ -388,12 +471,7 @@ def pycuda_compute_transient_fstat_map(multiFstatAtoms, windowRange):
     Returns
     -------
     FstatMap: pyTransientFstatMap
-        A 2D matrix `F_mn`,
-        with `m` an index over start-times `t0`,
-        and  `n` an index over duration parameters `tau`,
-        in steps of `dt0`  in `[t0,  t0+t0Band]`,
-        and `dtau` in `[tau, tau+tauBand]`
-        as defined in the `windowRange` input.
+        The computed results, see the class definition for details.
     """
 
     if windowRange.type >= lalpulsar.TRANSIENT_LAST:
