@@ -448,6 +448,44 @@ class TestWriter(BaseForTestsWithData):
         )
         self.assertTrue(os.path.isfile(expected_SFT_filepath))
 
+    def test_noise_sfts_narrowbanded(self):
+
+        # create some broad SFTs
+        writer = self.writer_class_to_test(
+            label="test_noiseSFTs_broad",
+            outdir=self.outdir,
+            duration=self.duration,
+            Tsft=self.Tsft,
+            tstart=self.tstart,
+            detectors="H1",
+            SFTWindowType=self.SFTWindowType,
+            SFTWindowBeta=self.SFTWindowBeta,
+            sqrtSX=self.sqrtSX,
+            Band=3,
+            F0=self.signal_parameters["F0"],
+        )
+        writer.make_data(verbose=True)
+        # split them by frequency
+        cl_split = "lalapps_splitSFTs --frequency-bandwidth 1"
+        cl_split += f" --start-frequency {writer.fmin}"
+        cl_split += f" --end-frequency {writer.fmin+writer.Band}"
+        cl_split += f" --output-directory {self.outdir}"
+        cl_split += f" -- {writer.sftfilepath}"
+        pyfstat.helper_functions.run_commandline(cl_split)
+        # reuse the split SFTs as noiseSFTs
+        NB_recycling_writer = self.writer_class_to_test(
+            label="test_noiseSFTs_recycle",
+            outdir=self.outdir,
+            SFTWindowType=self.SFTWindowType,
+            SFTWindowBeta=self.SFTWindowBeta,
+            noiseSFTs=os.path.join(self.outdir, "*NB*"),
+            F0=self.signal_parameters["F0"]
+            if self.writer_class_to_test.mfd.endswith("v4")
+            else None,
+            # **self.signal_parameters, # FIXME this will fail, need MFDv5 fix
+        )
+        NB_recycling_writer.make_data(verbose=True)
+
     def _test_writer_with_tsfiles(self, gaps=False):
         """helper function to rerun with/without gaps"""
         IFOs = self.multi_detectors.split(",")
@@ -1292,10 +1330,10 @@ class TestSearchForSignalWithJumps(TestBaseSearchClass):
                 [
                     1,
                     2 * np.pi * dT,
-                    2 * np.pi * dT ** 2 / 2.0,
-                    2 * np.pi * dT ** 3 / 6.0,
+                    2 * np.pi * dT**2 / 2.0,
+                    2 * np.pi * dT**3 / 6.0,
                 ],
-                [0, 1, dT, dT ** 2 / 2.0],
+                [0, 1, dT, dT**2 / 2.0],
                 [0, 0, 1, dT],
                 [0, 0, 0, 1],
             ]
@@ -1311,9 +1349,9 @@ class TestSearchForSignalWithJumps(TestBaseSearchClass):
         thetaB = np.zeros(len(thetaA))
         thetaB[3] = thetaA[3]
         thetaB[2] = thetaA[2] + thetaA[3] * dT
-        thetaB[1] = thetaA[1] + thetaA[2] * dT + 0.5 * thetaA[3] * dT ** 2
+        thetaB[1] = thetaA[1] + thetaA[2] * dT + 0.5 * thetaA[3] * dT**2
         thetaB[0] = thetaA[0] + 2 * np.pi * (
-            thetaA[1] * dT + 0.5 * thetaA[2] * dT ** 2 + thetaA[3] * dT ** 3 / 6.0
+            thetaA[1] * dT + 0.5 * thetaA[2] * dT**2 + thetaA[3] * dT**3 / 6.0
         )
 
         self.assertTrue(np.array_equal(thetaB, search._shift_coefficients(thetaA, dT)))
@@ -2224,11 +2262,6 @@ class TestGridSearch(BaseForTestsWithData):
         cl_CFSv2.append("--f1dot {} --f1dotBand 0".format(self.F1))
         cl_CFSv2.append("--DataFiles '{}'".format(self.Writer.sftfilepath))
         cl_CFSv2.append("--refTime {}".format(self.tref))
-        earth_ephem, sun_ephem = pyfstat.helper_functions.get_ephemeris_files()
-        if earth_ephem is not None:
-            cl_CFSv2.append('--ephemEarth="{}"'.format(earth_ephem))
-        if sun_ephem is not None:
-            cl_CFSv2.append('--ephemSun="{}"'.format(sun_ephem))
         cl_CFSv2.append("--outputFstat " + CFSv2_out_file)
         cl_CFSv2.append("--outputLoudest " + CFSv2_loudest_file)
         # to match ComputeFstat default (and hence PyFstat) defaults on older
@@ -2248,6 +2281,24 @@ class TestGridSearch(BaseForTestsWithData):
         self.assertTrue(np.max(np.abs(CFSv2_out["freq"] - pyfstat_out["F0"]) < 1e-16))
         self.assertTrue(np.max(np.abs(CFSv2_out["2F"] - pyfstat_out["twoF"]) < 1))
         self.assertTrue(np.max(CFSv2_out["2F"]) == np.max(pyfstat_out["twoF"]))
+        self.search.generate_loudest()
+        self.assertTrue(os.path.isfile(self.search.loudest_file))
+        loudest = {}
+        for run, f in zip(
+            ["CFSv2", "PyFstat"], [CFSv2_loudest_file, self.search.loudest_file]
+        ):
+            loudest[run] = pyfstat.helper_functions.read_par(
+                filename=f,
+                suffix="loudest",
+                raise_error=False,
+            )
+        for key in ["Alpha", "Delta", "Freq", "f1dot", "f2dot", "f3dot"]:
+            self.assertTrue(
+                np.abs(loudest["CFSv2"][key] - loudest["PyFstat"][key]) < 1e-16
+            )
+        self.assertTrue(
+            np.abs(loudest["CFSv2"]["twoF"] - loudest["PyFstat"]["twoF"]) < 1
+        )
 
     def test_semicoherent_grid_search(self):
         # FIXME this one doesn't check the results at all yet
